powered by
Calculating the temperature-change-voltage curve for a particular set of indices for each component corresponding to the values from a standard components space.
voltageCurve(Tdata, x, StdRes, StdTherm_Val, StdTherm_Beta)
the voltage values at Point B
a vector of temperature-change values
a vector of the indices of each component
a vector of available resistor values
a vector of available nominal thermistor resistances
a vector of of thermistor temperature coefficients
data(CompValues) Tdata <- seq(-40, 85, by=5) R_id <- c(2, 1, 4, 2, 1, 3) Res <- CompValues$Res ThVal <- CompValues$ThVal ThBeta <- CompValues$ThBeta voltageCurve(Tdata, R_id, Res, ThVal, ThBeta)
Run the code above in your browser using DataLab